Welcome to ClientVPS Mirrors

Help for package translit.uk
Title: Ukrainian to Latin Transliteration
Version: 1.0.2
Description: Provides a robust and user-friendly solution for transliterating Ukrainian strings into Latin symbols.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
URL: https://github.com/Amice13/translit.uk
BugReports: https://github.com/Amice13/translit.uk/issues
NeedsCompilation: no
Packaged: 2025-03-24 13:18:50 UTC; ZAKHAROK
Author: Kyrylo Zakharov ORCID iD [aut, cre]
Maintainer: Kyrylo Zakharov <kirillzakharov13@gmail.com>
Repository: CRAN
Date/Publication: 2025-03-24 14:10:02 UTC

Transliterate string in Ukrainian

Description

This function converts a given string from Ukrainian Cyrillic to Latin characters using a specific set of transliteration rules.

Usage

translit(string)

Arguments

string

A string in Ukrainian

Value

A string in Latin

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.